@@ -1,6 +1,7 @@
 package Media::Convert::FfmpegInfo;
 
 use MooseX::Singleton;
+use SemVer;
 
 has 'codecs' => (
 	is => 'ro',
@@ -43,4 +44,20 @@ sub _build_codecs {
 	return $rv;
 }
 
+has version => (
+	is => 'ro',
+	isa => 'SemVer',
+	lazy => 1,
+	builder => '_build_version',
+);
+
+sub _build_version {
+	open my $ffmpeg, "-|", "ffmpeg -version 2>/dev/null";
+	foreach my $line(<$ffmpeg>) {
+		if($line =~ /ffmpeg version ([0-9.]+)/) {
+			return SemVer->new($1);
+		}
+	}
+}
+
 1;
